---
Summary: Display basic collection from cards
Status: Done
---

# Description

A basic collection is a folder in the `scrum` folder containing md cards.

By default, all cards are in the inventory. There's no filters being applied at the moment.

For now, a card must have a summary. Other fields are optional. Fields are defined either in obsidian style properties:

```md
---
Property 1: Value
Property 2: Value
---
```

or by the text following a hash header with.

A card's index is currently its filename.

# Cucumber

**GIVEN** a collection of cards, and a collection folder _C_.
**WHEN** `sbl C` is run.
**THEN** a table showing the index and description all the cards in the collection is shown.
